@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright 2001-2022 Zabbix SIA
+** Copyright 2001-2023 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -22,6 +22,7 @@ import (
 
 	"git.zabbix.com/ap/mongodb/plugin/handlers"
 	"git.zabbix.com/ap/plugin-support/plugin"
+	"git.zabbix.com/ap/plugin-support/tlsconfig"
 	"git.zabbix.com/ap/plugin-support/uri"
 	"git.zabbix.com/ap/plugin-support/zbxerr"
 )
@@ -51,16 +52,24 @@ func (p *Plugin) Export(key string, rawParams []string, ctx plugin.ContextProvid
 		return nil, err
 	}
 
+	details, err := tlsconfig.CreateDetails(params["sessionName"], params["TLSConnect"],
+		params["TLSCAFile"], params["TLSCertFile"], params["TLSKeyFile"], params["URI"])
+	if err != nil {
+		return nil, zbxerr.ErrorInvalidConfiguration.Wrap(err)
+	}
+
 	handleMetric := getHandlerFunc(key)
 	if handleMetric == nil {
 		return nil, zbxerr.ErrorUnsupportedMetric
 	}
 
-	conn, err := p.connMgr.GetConnection(*uri)
+	conn, err := p.connMgr.GetConnection(*uri, details)
 	if err != nil {
 		// Special logic of processing connection errors should be used if mongodb.ping is requested
 		// because it must return pingFailed if any error occurred.
 		if key == keyPing {
+			p.Debugf(err.Error())
+
 			return handlers.PingFailed, nil
 		}
 
